@@ -6,7 +6,7 @@ use warnings;
 use Exporter qw(import);
 use XSLoader;
 
-our $VERSION    = '0.05';
+our $VERSION    = '0.06';
 our $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -65,7 +65,7 @@ L<Set::Product>
 =head1 REQUESTS AND BUGS
 
 Please report any bugs or feature requests to
-L<http://rt.cpan.org/Public/Bug/Report.html?Queue=Set-Product-XS>. I will be
+L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Set-Product-XS>. I will be
 notified, and then you'll automatically be notified of progress on your bug as
 I make changes.
 
@@ -83,21 +83,13 @@ You can also look for information at:
 
 L<https://github.com/gray/set-product-xs>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Set-Product-XS>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Set-Product-XS>
-
 =item * RT: CPAN's request tracker
 
-L<http://rt.cpan.org/Public/Dist/Display.html?Name=Set-Product-XS>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set-Product-XS>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/Set-Product-XS/>
+L<https://metacpan.org/release/Set-Product-XS>
 
 =back
 
